@@ -1,8 +1,8 @@
 """\
 Code generator functions for wxDatePickerCtrl objects
 
-@copyright: 2014 Carsten Grohmann
-@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+@copyright: 2014-2016 Carsten Grohmann
+@license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
 import common
@@ -10,11 +10,7 @@ import wcodegen
 
 
 class LispDatePickerCtrlGenerator(wcodegen.LispWidgetCodeWriter):
-
-    tmpl = '(setf %(name)s (%(klass)s_Create %(parent)s %(id)s ' \
-           '-1 -1 -1 -1 %(style)s))\n'
-
-# end of class LispDatePickerCtrlGenerator
+    tmpl = '(setf %(name)s (%(klass)s_Create %(parent)s %(id)s -1 -1 -1 -1 %(style)s))\n'
 
 
 def initialize():
